% This package designed and commented in russian utf-8 encoding.
%
% Класс журнала «Многофазные системы»
% Ранее класс журнала «Труды Института механики им. Р.Р. Мавлютова»
% на основе ГОСТ 2.105-95
% Автор — Константин Михайленко
% Лицензия GPL
% Все вопросы, замечания и пожелания ожидаются по адресу: mailto:const@uimech.org
%
% Параметры:
%  10pt, 11pt, 12pt — шрифт. По-умолчанию — 10pt
%  koi8-r, cp1251, utf8 — кодировка исхоного текста. По-умолчанию — utf8
%
% Предустановленные параметры
%  a4paper — размер бумаги
%  twocolumn - двухколоночный формат документа
%
% Уже подключены пакеты:
% mathpazo    - шрифты для оформления математики
% paratype    - основные шрифты текста
% hyperref    - подсветка о поддержка гиперссылок
% mathtext    - для русских букв в формулах
% fontenc     - кодировка шрифтов - T2A
% inputenc    - входная кодировка - задаётся параметром [utf8]
% babel       - настройки языков - русский и английский [english,russian]
% indentfirst - начинать абзацы с красной строки
% caption     - настройка вида заголовков таблиц и рисунков
% amssymb     - для русских «меньше или равно» «больше или равно»
% amsfonts    - для русских «меньше или равно» «больше или равно»
% graphicx    - для работы с графикой
% balance     - выравнивание колонок на послдней странице
% cite        - «умная» организация ссылок
% lastpage    - получение номера последней страницы
% microtype   - мелкие улучшения типографики
% qrcode      - генерация QR-кода
%
% Используемые определения для сборника
% \Year{}     - задаёт год издания
% \Volume{}   - задаёт номер выпуска
%
% \booktitle        - титульный лист и выходные данные
% \tableofcontents  - содержание
% \begin{preamble}…\end{preamble}  - предисловие
% \rearlist         - финальный лист


% Используемые определения для статьи
% \title{}
% \author{}
% \institute{}
% \UDC{}
% \abstract{}

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{mfs}[2019/03/19 v3.2 Non Standard LaTeX document class]

% v1.01 Проверка существования команды \No
% v1.02 «Красивые» символы больше-или-равно, меньше-или-равно
% v1.03 Включен DOI-индекс
% v1.04 Прямые греческие буквы (ГОСТ)
% v1.05 Исправлен URL
% v1.06 Исправлен глюк с Ё
% v1.07 Добавлено ISSN
% v1.07,1 Добавлен QR-код
% v2.0 Изменены шрифты, добавлена работа с гиперссылками, изменена «шапка»
% v2.01 Добавлен режим draft
% v3 Multiphase Systems
% v3.1 Генерируем обложку (команда \cover)
% v3.2 Добавлен cmap для работы с русским языком в pdf

% v1.06 Исправлен глюк с Ё (кодировка 1251 «по умолчанию» была не определена)
\newcommand\UIM@encoding{cp1251}
\DeclareOption{koi8-r}{\renewcommand\UIM@encoding{koi8-r}}
\DeclareOption{utf8}{\renewcommand\UIM@encoding{utf8}}
\DeclareOption{cp1251}{\renewcommand\UIM@encoding{cp1251}}

% v2.01 Добавлен режим draft
\newcommand\UIM@draft{twocolumn}
\DeclareOption{draft}{\renewcommand\UIM@draft{draft}}

\ProcessOptions
% v2.01 Добавлен режим draft
\LoadClass[9pt,a4paper,\UIM@draft]{article}

% v2.0 Изменены шрифты
\RequirePackage[T2A,T1]{fontenc}
\RequirePackage{mathpazo}
\RequirePackage{paratype}

% v2.0 добавлена работа с гиперссылками.
\RequirePackage[colorlinks=true,citecolor=blue,urlcolor=blue,linkcolor=blue,pdftex]{hyperref}

\RequirePackage{cuted}
\RequirePackage{mathtext}
\RequirePackage[\UIM@encoding]{inputenc}
\RequirePackage[english,russian]{babel}
\RequirePackage{indentfirst}
\RequirePackage[pdftex]{graphicx}
\RequirePackage{tikz}
\RequirePackage{amsfonts}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{caption}
\RequirePackage{balance}
\RequirePackage{cite}
\RequirePackage{lastpage}
% v2.0 мелкие типографские улучшения
\RequirePackage{microtype}
% v1.07,1 Добавлен QR-код
\RequirePackage{qrcode}
\RequirePackage{dblfloatfix}
\RequirePackage{cmap}

\captionsetup{labelsep=period,textformat=simple,format=hang,font={sf,small},margin=.5cm}

\setlength\paperheight{297mm}
\setlength\paperwidth{210mm}
\setlength\voffset{0mm}
\setlength\hoffset{0mm}
\setlength\textheight{230mm}
\setlength\textwidth{170mm}
\setlength\topmargin{1.6mm}
\setlength\headheight{5mm}
\setlength\headsep{8mm}
\setlength\footskip{0mm}
\setlength\oddsidemargin{-5.4mm}
\setlength\evensidemargin{-5.4mm}
\setlength\columnsep{5mm}
\setlength\columnseprule{0mm}

\@twosidetrue

%% Установка общих переменных
\newcommand{\UIM@Volume}{11}%11}
\newcommand{\Volume}[1]{\renewcommand{\UIM@Volume}{#1}}
%
\newcommand{\UIM@Year}{2016}
\newcommand{\Year}[1]{\renewcommand{\UIM@Year}{#1}}
%
\newcommand{\UIM@Number}{1}%1}
\newcommand{\Number}[1]{\renewcommand{\UIM@Number}{#1}}
%
\newcommand{\UIM@Article}{000}%1}
\newcommand{\Article}[1]{\renewcommand{\UIM@Article}{#1}}
%
\newcommand{\UIM@Startpage}{1}%1}
\newcommand{\Startpage}[1]{\renewcommand{\UIM@Startpage}{#1}\setcounter{page}{#1}}
%
\newcommand{\UIM@Endpage}{\pageref{LastPage}}%1}
\newcommand{\Endpage}[1]{\renewcommand{\UIM@Endpage}{#1}}
%
\newcommand{\UIM@Income}{\today}%1}
\newcommand{\Incomedate}[1]{\renewcommand{\UIM@Income}{#1}}
%
\newcommand{\UIM@Output}{\today}%1}
\newcommand{\Outputdate}[1]{\renewcommand{\UIM@Output}{#1}}
%
\newcommand{\UIM@CopyRight}{\hbox{}\\\copyright\ \CYRI\cyrn\cyrs\cyrt\cyri\cyrt\cyru\cyrt\ 
\cyrm\cyre\cyrh\cyra\cyrn\cyri\cyrk\cyri\ \cyri\cyrm.\ \CYRR.\CYRR.\ \CYRM\cyra\cyrv\cyrl\cyryu\cyrt\cyro\cyrv\cyra\ 
\CYRU\CYRF\CYRI\CYRC\ \CYRR\CYRA\CYRN}
\newcommand{\UIM@Copyright}{\UIM@CopyRight}
\newcommand{\Copyright}[1]{\renewcommand{\UIM@Copyright}{\UIM@CopyRight\\#1}}
%
% Установка переменных для статьи
\newcommand{\@UDC}{00.00}
\newcommand{\UDC}[1]{\renewcommand{\@UDC}{#1}}
%
\newcommand{\@KeyWords}{}
\newcommand{\keywords}[1]{\gdef\@KeyWords{\parbox{155mm}{%
  \hspace*{5.5mm}\small\ignorespaces{%
  \par\noindent\textbf{\iflanguage{russian}{\CYRK\cyrl\cyryu\cyrch\cyre\cyrv\cyrery\cyre\ %
  \cyrs\cyrl\cyro\cyrv\cyra:}{Keywords:}}\ #1}}}%
}
%

%\newcommand{\institute}[1]{\date{#1}}
\let\institute\date

% v1.01 Проверка существования команды \No
\ifx\No\undefined
 \newcommand{\No}{\cyr\textnumero}
\fi

% v1.02 «Красивые» символы больше-или-равно, меньше-или-равно
\renewcommand{\le}{\ensuremath{\leqslant}}
\renewcommand{\leq}{\ensuremath{\leqslant}}
\renewcommand{\ge}{\ensuremath{\geqslant}}
\renewcommand{\geq}{\ensuremath{\geqslant}}

\newcommand{\J@Name}{\iflanguage{russian}{\CYRM\cyrn\cyro\cyrg\cyro\cyrf\cyra\cyrz\cyrn\cyrery\cyre\ 
  \cyrs\cyri\cyrs\cyrt\cyre\cyrm\cyrery}{Multiphase Systems}}

\renewcommand{\@oddhead}%
 {{\vbox{
 \hbox to\textwidth{{\small\sf{\iflanguage{russian}{\UIM@Year.\ \CYRT.\ \UIM@Volume.\ %
 \No\,\UIM@Number}{\UIM@Volume (\UIM@Year)\ \textbf{\UIM@Number}}}\hfill\small\thepage}\strut}
   \hrule}}}
\renewcommand{\@evenhead}%
 {\vbox{{\hbox to\textwidth{\small\thepage\hfill\sf{\J@Name}}
   {\hrule}}}}
\renewcommand{\@oddfoot}{}
\renewcommand{\@evenfoot}{}

\newcommand\@abstract{}
\renewcommand{\abstract}[1]{\gdef\@abstract{\parbox{155mm}{%
  \hspace*{5.5mm}\small\ignorespaces{\par\noindent#1}}}%
}

\newcommand{\toEnglish}{\newpage\selectlanguage{english}}

\newcommand{\doi}[1]{\href{https://doi.org/#1}{DOI: #1}}

%\begin{tikzpicture}[y=1.pt, x=1.pt,yscale=-.19,xscale=.19, inner sep=0pt, outer sep=0pt]
%  \path[cm={{0.89474,0.0,0.0,0.89474,(15.78947,15.78947)}}
%  \path[cm={{0.78571,0.0,0.0,0.78571,(32.14286,32.14286)}}
%  \path[cm={{0.55556,0.0,0.0,0.55556,(66.66667,66.66667)}}
%  \path[draw=black,line join=round,line cap=round,miter limit=4.00,line width=.700pt]
%    (2230,270) .. controls (659.2057,270) and (323.8832,270) .. (300,270) .. controls (245,270) and
%    (255,50) .. (240,50) .. controls (225,50) and (235,175) .. (215,175) .. controls (200,175) and
%    (205,125) .. (195,125) .. controls (185,125) and (185,160) .. (175,160) .. 
%    controls (165.2376,160) and (170,150) .. (160,150) .. controls (140.3105,150) and
%    (164.8122,150) .. (150,150);

\newcommand{\logograph}[2]{
	\path[draw=black,line width=.5pt] (.5*#1,15*#1)arc(0:135:-14.5*#1);
	\path[draw=black,line width=.5pt] (.5*#1,15*#1)arc(0:-125:-14.5*#1);
	\path[draw=black,line width=1pt] (3.5*#1,15*#1)arc(0:135:-11.5*#1);
	\path[draw=black,line width=1pt] (3.5*#1,15*#1)arc(0:-125:-11.5*#1);
	\path[cm={{0.9,0.0,0.0,0.9,(1.6*#1,1.6*#1)}},draw=black,line width=1.5pt] (5.5*#1,15*#1)arc(0:135:-9.5*#1);
	\path[cm={{0.9,0.0,0.0,0.9,(1.6*#1,1.6*#1)}},draw=black,line width=1.5pt] (5.5*#1,15*#1)arc(0:-135:-9.5*#1);
	\path[cm={{0.8,0.0,0.0,0.8,(3.2*#1,3.2*#1)}},draw=black,line width=2pt] (8*#1,15*#1)arc(0:135:-7*#1);
	\path[cm={{0.8,0.0,0.0,0.8,(3.2*#1,3.2*#1)}},draw=black,line width=2pt] (8*#1,15*#1)arc(0:-135:-7*#1);
	\path[cm={{0.56,0.0,0.0,0.56,(6.7*#1,6.7*#1)}},draw=black,line width=2.5pt] (10.5*#1,15*#1)arc(0:135:-4.5*#1);
	\path[cm={{0.56,0.0,0.0,0.56,(6.7*#1,6.7*#1)}},draw=black,line width=2.5pt] (10.5*#1,15*#1)arc(0:-135:-4.5*#1);
	\path[draw=black,line join=round,line cap=round,miter limit=4,line width=.7pt] (73*#1*#2,3*#1) .. controls (65.9*#1,3*#1) and (32.4*#1,3*#1) .. (30*#1,3*#1) .. controls (24.5*#1,3*#1) and (25.5*#1,25*#1) .. (24*#1,25*#1) .. controls (22.5*#1,25*#1) and (23.5*#1,11*#1) .. (21.5*#1,11*#1) .. controls (20*#1,11*#1) and (20.5*#1,17.5*#1) .. (19.5*#1,17.5*#1) .. controls (18.5*#1,17.5*#1) and (18.5*#1,14*#1) .. (17.5*#1,14*#1) .. controls (16.5*#1,14*#1) and (17*#1,15*#1) .. (16*#1,15*#1) .. controls (14*#1,15*#1) and (16.5*#1,15*#1) .. (15*#1,15*#1);}

\newcommand{\putlogo}{
	\begin{tikzpicture}
		\logograph{.065}{3.14}
		\path[fill=black] (22mm,4mm) node[above right] {\usefont{T2A}{PTSerifCaption-TLF}{m}{ui} \Huge\scalebox{1.2}{\hbox{\iflanguage{english}{\quad}{}\J@Name}}};
	\end{tikzpicture}
}
\newcommand{\putlogoimech}{
%	\begin{tikzpicture}
		\logograph{.08}{1}
		\path(2.38,.9) node[above right] {\Huge\scalebox{1.35}{\CYRI\CYRM\cyre\cyrh}};
		\path(2.42,.4) node[above right] {\scalebox{.95}{\cyri\cyrm.\ \CYRR.\CYRR.\,\CYRM\cyra\cyrv\cyrl\cyryu\cyrt\cyro\cyrv\cyra}};
%	\end{tikzpicture}
}

\newcounter{mnth}
\newcommand{\UIM@Month}{
	\setcounter{mnth}{\UIM@Number}
	\ifcase\themnth
	\or
	\CYRYA\cyrn\cyrv\cyra\cyrr\cyrsftsn--\CYRM\cyra\cyrr\cyrt
	\or
	\CYRA\cyrp\cyrr\cyre\cyrl\cyrsftsn--\CYRI\cyryu\cyrn\cyrsftsn
	\or
	\CYRI\cyryu\cyrl\cyrsftsn--\CYRS\cyre\cyrn\cyrt\cyrya\cyrb\cyrr\cyrsftsn
	\else
	\CYRO\cyrk\cyrt\cyrya\cyrb\cyrr\cyrsftsn--\CYRD\cyre\cyrk\cyra\cyrb\cyrr\cyrsftsn
	\fi
}

\newcommand{\cover}{
	\thispagestyle{empty}
	\vspace*{-40mm}
	\noindent\hspace*{-109.5mm}
	\definecolor{b1}{HTML}{2F2483}
	\definecolor{b2}{HTML}{A199CB}
	\begin{tikzpicture}
	\usefont{T2A}{PTSerif-TLF}{b}{n}
	\draw[color=white](0,0)--(21,29.7);
	\draw (5,26.5) node [above,left] {\qrcode[nolink,height=25mm]{http://mfs.uimech.org/mfs\UIM@Year.\UIM@Number}};
	\draw (19.8,27) node [above,left] {\large\scalebox{1.4}{ISSN: 2658--5782}};
	\draw (5.5,25.5) node [above,right] {\Large\scalebox{1.5}{\CYRN\cyro\cyrm\cyre\cyrr\ \UIM@Number}};
	\draw (19.8,25.5) node [above,left] {\Large\scalebox{1.5}{\UIM@Month\ \UIM@Year}};
	\draw[color=b1,fill=b1,line width=1pt] (0,14.5)--(5,14.5)--(5,24.5)--(0,24.5)--cycle;
	\draw[color=b1,fill=b1,line width=1pt] (5.5,14.5)--(21,14.5)--(21,24.5)--(5.5,24.5)--cycle;
	\path[text=white] (6,22) node[above right] {\Huge\scalebox{1.9}{\CYRM\CYRN\CYRO\CYRG\CYRO\CYRF\CYRA\CYRZ\CYRN\CYRERY\CYRE}};
	\path[text=white] (6,20) node[above right] {\Huge\scalebox{1.9}{\CYRS\CYRI\CYRS\CYRT\CYRE\CYRM\CYRERY}};
	\draw[color=b1,fill=b2] (12.5,13.5)--(18.5,13.5)--(18.5,15.5)--(12.5,15.5)--cycle;
	\draw[color=b1] (12.7,13.7)--(18.3,13.7)--(18.3,15.3)--(12.7,15.3)--cycle;
	\draw[color=b1] (12.5,13.5)--(12.7,13.7);
	\draw[color=b1] (12.5,15.5)--(12.7,15.3);
	\draw[color=b1] (18.5,13.5)--(18.3,13.7);
	\draw[color=b1] (18.5,15.5)--(18.3,15.3);
	\draw (15.5,14.5) node[text=b1] {\Large\scalebox{1.2}{mfs.uimech.org}};
	
	\put(160,100){\putlogoimech};
	\end{tikzpicture}
}

\newcommand{\UIM@copyright}{
  \renewcommand{\@makefnmark}{}
  \footnote{\UIM@Copyright}
  \renewcommand{\@makefnmark}{\mbox{$^{\@thefnmark}$}}
  \addtocounter{footnote}{-1}
}

% v2.0 Массовое изменение «шапки»
\def\@maketitle{\nobalance%
  \vbox{\vspace*{-10mm}\thispagestyle{empty}
   \textsf{\scriptsize %ISSN 2542--0380 
   \hfill\scriptsize
   \iflanguage{russian}{\CYRT\cyro\cyrm\ \UIM@Volume\ (\UIM@Year),\ \No\,\UIM@Number,\ %
   \cyrs.\ \UIM@Startpage--\UIM@Endpage}{\UIM@Volume\ (\UIM@Year),\ \textbf{\UIM@Number},\ %
   \UIM@Startpage--\UIM@Endpage}}\\[-.5mm]
   \rule[2mm]{\textwidth}{.2mm} \\[-1mm] 
   \hbox{\putlogo}\hspace*{0mm}\raisebox{9mm}{\qrcode{http://mfs.uimech.org/mfs\UIM@Year.\UIM@Number.\UIM@Article}}
   \\ \rule[2.7mm]{\textwidth}{.2mm}\\[-3.9mm]
% v1.05 Исправлен URL
% v3.00 Замена uim -> mfs
   \textsf{\scriptsize \url{http://mfs.uimech.org/mfs\UIM@Year.\UIM@Number.\UIM@Article}}\hfill
   \textsf{\scriptsize \iflanguage{russian}{\CYRP\cyro\cyrl\cyru\cyrch\cyre\cyrn\cyra}{Received}: %
   \UIM@Income}\\[-1.5mm]
% v1.03 Включен DOI-индекс
% v3.00 Замена uim -> mfs
   \textsf{\vbox{}\scriptsize \href{https://doi.org/10.21662/mfs\UIM@Year.\UIM@Number.\UIM@Article}{DOI: 10.21662/mfs\UIM@Year.\UIM@Number.\UIM@Article}}
   \hfill
   \textsf{\scriptsize \iflanguage{russian}{\CYRP\cyrr\cyri\cyrn\cyrya\cyrt\cyra}{Accepted}: %
   \UIM@Output}\\[-1.5mm]
   \iflanguage{russian}{\textsf{\vbox{}\scriptsize \CYRU\CYRD\CYRK\ \@UDC}\hfill}{}
    \begin{center}
   \vspace*{10mm}\par
    {\LARGE%\sffamily\bfseries\upshape
    \usefont{T2A}{PTSansCaption-TLF}{b}{n}\@title\par\vspace*{1mm}}%
    \vskip12pt plus.1fil minus6pt%
    {\sffamily\bfseries\@author\par\vspace*{-3mm}}%
    \vskip6pt plus.1fil minus3pt%
    \vspace*{3mm}%
    {\sffamily\@date\par}
    \vskip2em plus.1fil minus1ex%
    {\sffamily\@abstract}%
    \vskip.5em plus.5em minus1ex%
    {\sffamily\@KeyWords}
    \vskip2em plus1em minus1ex%
    \par
  \end{center}
  }%
}

\renewcommand\maketitle{\par
  \setcounter{footnote}{0}%
  \begingroup
    \if@twocolumn
      \twocolumn[\@maketitle]%
    \else
      \global\@topnum\z@
      \@maketitle%\@thanks
    \fi
    \iflanguage{russian}{\@thanks \UIM@copyright}{}
  \endgroup
  \vspace*{-2.3
  	em}
  \setcounter{equation}{0}
  \setcounter{section}{0}
  \setcounter{figure}{0}
  \setcounter{table}{0}
}



\newcommand{\makeengtitle}[5]{\balance\onecolumn%
  \vbox{\vspace*{-10mm}\thispagestyle{empty}
   \textsf{\scriptsize ISSN 2542--0380 \hfill \scriptsize \CYRT\cyro\cyrm\ \UIM@Volume\ (\UIM@Year),\ \No\,\UIM@Number,\ \cyrs.\ \UIM@Startpage--\UIM@Endpage}\\[-.5mm]
   \rule[2mm]{\textwidth}{.2mm} \\[-1mm] 
% v3.00 Замена uim -> mfs
   \hbox{\putlogo\EnName}\hspace*{0mm}\raisebox{9mm}{\qrcode{http://mfs.uimech.org/mfs\UIM@Year.\UIM@Number.\UIM@Article}}
   \\ \rule[2.7mm]{\textwidth}{.2mm}\\[-3.9mm]
% v1.05 Исправлен URL
% v3.00 Замена uim -> mfs
   \textsf{\scriptsize \url{http://mfs.uimech.org/mfs\UIM@Year.\UIM@Number.\UIM@Article}}\hfill
   \textsf{\scriptsize \CYRP\cyro\cyrl\cyru\cyrch\cyre\cyrn\cyra: \UIM@Income}\\[-1.5mm]
% v1.03 Включен DOI-индекс
% v3.00 Замена uim -> mfs
   \textsf{\vbox{}\scriptsize \href{https://doi.org/10.21662/mfs\UIM@Year.\UIM@Number.\UIM@Article}{DOI: 10.21662/mfs\UIM@Year.\UIM@Number.\UIM@Article}}
   \hfill
   \textsf{\scriptsize \CYRP\cyrr\cyri\cyrn\cyrya\cyrt\cyra: \UIM@Output}\\[-1.5mm]
   \textsf{\vbox{}\scriptsize \CYRU\CYRD\CYRK\ \@UDC}\hfill
    \begin{center}
   \vspace*{10mm}\par
    {\LARGE%\sffamily\bfseries\upshape
    \usefont{T2A}{PTSansCaption-TLF}{b}{n}#1\par\vspace*{1mm}}%
    \vskip12pt plus.1fil minus6pt%
    {\sffamily\bfseries#2\par\vspace*{-3mm}}%
    \vskip6pt plus.1fil minus3pt%
    \vspace*{3mm}%
    {\sffamily#3\par}
    \vskip2em plus.1fil minus1ex%
    {\sffamily#4}%
    \vskip.5em plus.5em minus1ex%
    {\sffamily\textbf{Keywords: }#5}
    \vskip2em plus1em minus1ex%
    \par
  \end{center}
  }%
%}
%%\newcommand\makeengtitle[5]{\balance\onecolumn%
%%  \vbox{
%  \vspace*{10mm}
%   \noindent\rule[2mm]{\textwidth}{.3mm}\\
%%    \begin{center}
%%   \vspace*{10mm}\par
%%    {\LARGE%\sffamily\bfseries\upshape
% v2.0 Изменены шрифты
%%    \usefont{T2A}{PTSansCaption-TLF}{b}{n}#1\par\vspace*{1mm}}%
%%    \vskip12pt plus.1fil minus6pt%
%%    {\sffamily\bfseries#2\par\vspace*{-3mm}}%
%%    \vskip6pt plus.1fil minus3pt%
%%    \vspace*{3mm}%
%%    {\sffamily#3\par}
%%  \end{center}
%%    \vskip2em plus.1fil minus1ex%
%%    {\sffamily \noindent#4}%
%%    \vskip.5em plus.5em minus1ex%
%%    {\sffamily\noindent\textbf{Keywords: }#5}
%%    \vskip2em plus1em minus1ex%
%%    \par
%%  }%
  
% v1.07,1 Добавлен QR-код
%  \vfill\noindent{\ \hfill\qrcode{http://mfs.uimech.org/mfs\UIM@Year.\UIM@Number.\UIM@Article}}

% Для конференции
   \vspace{5mm}
   \noindent\rule[2mm]{\textwidth}{.3mm} \\
   \parbox[t][0cm][c]{0cm}{\vspace*{7mm}\includegraphics[height=1.7cm]{conf2017-logo}}
   \hfill%\par
   \makebox[0cm][r]{
   \hbox{}\hfill\hbox{\vbox{}\hfill\textsf{\CYRS\cyrt\cyra\cyrt\cyrsftsn\cyrya\ 
   \cyrr\cyre\cyrk\cyro\cyrm\cyre\cyrn\cyrd\cyro\cyrv\cyra\cyrn\cyra\ \cyrk\ 
   \cyrp\cyru\cyrb\cyrl\cyri\cyrk\cyra\cyrc\cyri\cyri}}}\\[1mm]%
   \hbox{}\hfill\hbox{\textsf{\CYRP\cyrr\cyro\cyrg\cyrr\cyra\cyrm\cyrm\cyrn\cyrery\cyrm\ 
   \cyrk\cyro\cyrm\cyri\cyrt\cyre\cyrt\cyro\cyrm\ VI\ 
   \CYRR\cyro\cyrs\cyrs\cyri\cyrishrt\cyrs\cyrk\cyro\cyrishrt\ 
   \cyrk\cyro\cyrn\cyrf\cyre\cyrr\cyre\cyrn\cyrc\cyri\cyri}}\\[1mm]
   \hbox{}\hfill\hbox{\textsf{<<\CYRM\cyrn\cyro\cyrg\cyro\cyrf\cyra\cyrz\cyrn\cyrery\cyre\ 
   \cyrs\cyri\cyrs\cyrt\cyre\cyrm\cyrery:\ \cyrm\cyro\cyrd\cyre\cyrl\cyri,\ 
   \cyrerev\cyrk\cyrs\cyrp\cyre\cyrr\cyri\cyrm\cyre\cyrn\cyrt,\ 
   \cyrp\cyrr\cyri\cyrl\cyro\cyrzh\cyre\cyrn\cyri\cyrya>>}}\\
   \rule[1mm]{\textwidth}{.3mm}
}


%
\renewcommand{\figurename}{\CYRR\cyri\cyrs\cyru\cyrn\cyro\cyrk\ }
\renewcommand\thesection{\@arabic\c@section.}
\renewcommand\thesubsection{\thesection\@arabic\c@subsection.}
\renewcommand\section{\@startsection{section}{1}{\z@}%
                                   {1.5ex \@plus .3ex \@minus .1ex}%
                                   {.8ex \@plus.2ex}%
                                   {\normalfont\large\usefont{T2A}{PTSansCaption-TLF}{b}{n}}}
                                   %\sffamily\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                   {-1.5ex \@plus -1ex \@minus -.2ex}%
                                   {.8ex \@plus.2ex}%
                                   {\normalfont\usefont{T2A}{PTSansCaption-TLF}{b}{n}}}
                                   %\sffamily\bfseries}}
%
\renewenvironment{thebibliography}[1]
     {\balance\section*{\refname}%
      \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
            \small \scriptsize\usefont{T2A}{PTSansCaption-TLF}{m}{n}
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}


\setlength{\parindent}{2em}

\newcommand\superscript[1]{${}^{#1}$}


% v1.04 Прямые греческие буквы (ГОСТ)
\DeclareSymbolFont{lettersA}{U}{txmia}{m}{it} 
\SetSymbolFont{lettersA}{bold}{U}{txmia}{bx}{it} 
\DeclareFontSubstitution{U}{txmia}{m}{it} 
\DeclareSymbolFontAlphabet{\mathfrak}{lettersA}

\DeclareMathSymbol{\alphaup}{\mathord}{lettersA}{11}
\DeclareMathSymbol{\betaup}{\mathord}{lettersA}{12}
\DeclareMathSymbol{\gammaup}{\mathord}{lettersA}{13}
\DeclareMathSymbol{\deltaup}{\mathord}{lettersA}{14}
\DeclareMathSymbol{\epsilonup}{\mathord}{lettersA}{15}
\DeclareMathSymbol{\zetaup}{\mathord}{lettersA}{16}
\DeclareMathSymbol{\etaup}{\mathord}{lettersA}{17}
\DeclareMathSymbol{\thetaup}{\mathord}{lettersA}{18}
\DeclareMathSymbol{\iotaup}{\mathord}{lettersA}{19}
\DeclareMathSymbol{\kappaup}{\mathord}{lettersA}{20}
\DeclareMathSymbol{\lambdaup}{\mathord}{lettersA}{21}
\DeclareMathSymbol{\muup}{\mathord}{lettersA}{22}
\DeclareMathSymbol{\nuup}{\mathord}{lettersA}{23}
\DeclareMathSymbol{\xiup}{\mathord}{lettersA}{24}
\DeclareMathSymbol{\piup}{\mathord}{lettersA}{25}
\DeclareMathSymbol{\rhoup}{\mathord}{lettersA}{26}
\DeclareMathSymbol{\sigmaup}{\mathord}{lettersA}{27}
\DeclareMathSymbol{\tauup}{\mathord}{lettersA}{28}
\DeclareMathSymbol{\upsilonup}{\mathord}{lettersA}{29}
\DeclareMathSymbol{\phiup}{\mathord}{lettersA}{30}
\DeclareMathSymbol{\chiup}{\mathord}{lettersA}{31}
\DeclareMathSymbol{\psiup}{\mathord}{lettersA}{32}
\DeclareMathSymbol{\omegaup}{\mathord}{lettersA}{33}
\DeclareMathSymbol{\varepsilonup}{\mathord}{lettersA}{34}
\DeclareMathSymbol{\varthetaup}{\mathord}{lettersA}{35}
\DeclareMathSymbol{\varpiup}{\mathord}{lettersA}{36}
\DeclareMathSymbol{\varrhoup}{\mathord}{lettersA}{37}
\DeclareMathSymbol{\varsigmaup}{\mathord}{lettersA}{38}
\DeclareMathSymbol{\varphiup}{\mathord}{lettersA}{39}

\renewcommand{\alpha}{\alphaup}
\renewcommand{\beta}{\betaup}
\renewcommand{\gamma}{\gammaup}
\renewcommand{\delta}{\deltaup}
\renewcommand{\epsilon}{\epsilonup}
\renewcommand{\zeta}{\zetaup}
\renewcommand{\eta}{\etaup}
\renewcommand{\theta}{\thetaup}
\renewcommand{\iota}{\iotaup}
\renewcommand{\kappa}{\kappaup}
\renewcommand{\lambda}{\lambdaup}
\renewcommand{\mu}{\muup}
\renewcommand{\nu}{\nuup}
\renewcommand{\xi}{\xiup}
\renewcommand{\pi}{\piup}
\renewcommand{\rho}{\rhoup}
\renewcommand{\sigma}{\sigmaup}
\renewcommand{\tau}{\tauup}
\renewcommand{\upsilon}{\upsilonup}
\renewcommand{\phi}{\phiup}
\renewcommand{\chi}{\chiup}
\renewcommand{\psi}{\psiup}
\renewcommand{\omega}{\omegaup}
\renewcommand{\vartheta}{\varthetaup}
\renewcommand{\varpi}{\varpiup}
\renewcommand{\varrho}{\varrhoup}
\renewcommand{\varsigma}{\varsigmaup}
\renewcommand{\varepsilon}{\varepsilonup}
\renewcommand{\varphi}{\varphiup}

\endinput
%